==> Blind-src-V2.44.zip: Blind-2.44/protos/report.h <==
/*
 * $ID$
 * 
 * $Log: report.h,v $
 * Revision 2.44  1995/12/31  19:45:18  zeus
 * *** empty log message ***
 *
 * Revision 2.43  1995/03/20  01:43:09  zeus
 * Revision 2.42  1994/05/17  13:43:15  bampton
 * Revision 2.40  1994/03/09  20:22:55  bampton
 * Revision 2.37  1993/09/07  20:47:59  bampton
 * Revision 2.33  1993/08/03  23:10:13  bampton 
 * Revision 2.30  1993/07/14  14:59:26  bampton Full RCS version 
 * Revision 0.0   1993/07/14  13:42:55  bampton RCS prototype.
 * 
 */


/* Local to report.c proto-types for report.c */
void rpf (double x);
double wrap (double coord);
void fs (char *s);
void ff (double a);
void fi (int n);
void printplanet (planet * p, player * P);
int canseegroup (player * P, group * g);
void printgroup (player * owner, group * g, int printno,int fleetflag);
void putmap (double x1, double y1, double x2, double y2, double x, double y, int c);
void report_player_status (double *max, double *pop, double *ind, int *i, 
  int *j, player * P, player * P2, int gm);
void guess_techs (player * P, player * P2);
void print_status (player * P,int num);
void print_shiptypes (player * P, int flag);
void print_battles (player * P);
void print_bombings (player * P);
void print_incoming (player * P, planet *p);
void domap (player * P);
void in_production (planet * p);
int status (player * P1, player * P2);
int scrsize (double a, double b);
void spf (char *s, double x);
void print_options (player *P);
void option_on (char *ps, int opt, int popt);
void print_player_groups_in_battle (player *P, participant *PA);
void print_groups_at_planet (player * P, planet * p);
void print_unowned_planets (player * P);
void print_partial_reports (player * P);
void calc_status_mass (player *P, player *P2, int * num, double * mass, 
                       double *techmass, int flag);
void print_selective_defenses (player *P);
void print_routes (player *P);
void print_all_your_groups (player *P);
void print_alien_groups (player *P);
void print_alien_planets (player *P);
void print_full_planet (player *P, planet *p);
void print_full_your_planets (player *P);
void print_full_alien_planets (player *P);
void print_uninhabited_planets (player *P);
void print_unknown_planets (player *P);
void print_selective_def_at_p (player *P, planet *p);
void print_your_fleets (player *P);
void print_fleets_at_planet (player *P, planet *p);
int numinclass (shiptype *T,player *P,int flag);
void ckunderscores (char *s);
int player_dead (player *P);
int player_footnote (player *P);

#define ison(opt,optflag) (opt&optflag ? TRUE : FALSE)
#define SOMEEXIST -1

==> Blind-src-V2.45.zip: Blind-2.45/protos/report.h <==
/*
 * $ID$
 * 
 * $Log: report.h,v $
 * Revision 2.45  1997/01/01  00:14:47  zeus
 * *** empty log message ***
 *
 * Revision 2.44  1995/12/31  19:45:18  zeus
 * Revision 2.43  1995/03/20  01:43:09  zeus
 * Revision 2.42  1994/05/17  13:43:15  bampton
 * Revision 2.40  1994/03/09  20:22:55  bampton
 * Revision 2.37  1993/09/07  20:47:59  bampton
 * Revision 2.33  1993/08/03  23:10:13  bampton 
 * Revision 2.30  1993/07/14  14:59:26  bampton Full RCS version 
 * Revision 0.0   1993/07/14  13:42:55  bampton RCS prototype.
 * 
 */


/* Local to report.c proto-types for report.c */
void rpf (double x);
double wrap (double coord);
void fs (char *s);
void ff (double a);
void fi (int n);
void printplanet (planet * p, player * P);
int canseegroup (player * P, group * g);
void printgroup (player * owner, group * g, int printno,int fleetflag);
void putmap (double x1, double y1, double x2, double y2, double x, double y, int c);
void report_player_status (double *max, double *pop, double *ind, int *i, 
  int *j, player * P, player * P2, int gm);
void guess_techs (player * P, player * P2);
void print_status (player * P,int num);
void print_shiptypes (player * P, int flag);
void print_battles (player * P);
void print_bombings (player * P);
void print_incoming (player * P, planet *p);
void domap (player * P);
void in_production (planet * p);
int status (player * P1, player * P2);
int scrsize (double a, double b);
void spf (char *s, double x);
void print_options (player *P);
void option_on (char *ps, int opt, int popt);
void print_player_groups_in_battle (player *P, participant *PA);
void print_groups_at_planet (player * P, planet * p);
void print_unowned_planets (player * P);
void print_partial_reports (player * P);
void calc_status_mass (player *P, player *P2, int * num, double * mass, 
                       double *techmass, int flag);
void print_selective_defenses (player *P);
void print_routes (player *P);
void print_all_your_groups (player *P);
void print_alien_groups (player *P);
void print_alien_planets (player *P);
void print_full_planet (player *P, planet *p);
void print_full_your_planets (player *P);
void print_full_alien_planets (player *P);
void print_uninhabited_planets (player *P);
void print_unknown_planets (player *P);
void print_selective_def_at_p (player *P, planet *p);
void print_your_fleets (player *P);
void print_fleets_at_planet (player *P, planet *p);
int numinclass (shiptype *T,player *P,int flag);
void ckunderscores (char *s);
int player_dead (player *P);
int player_footnote (player *P);
void print_battle_sum (player *P);
void print_bombing_summary (player *P);
void add_bomb_rec (bombing *b, bombsum *br, int flag);

#define ison(opt,optflag) (opt&optflag ? TRUE : FALSE)
#define SOMEEXIST -1

#define PG_SIMP_BATTLE 0
#define PG_NO_NUM      1
#define PG_FULL        2
#define PG_BATSUM      3

#define SAW_IT   1
#define NOT_SEEN 0
